// Citaj.cs Citanje podataka standardnih tipova iz ulaznog toka,
//          iz datoteke i s glavnog ulaza.

using System;
using System.IO;

namespace Usluge {
  public class Citaj {
    private TextReader ut;   // Ulazni tok iz kojeg se cita.
    private char c;          // Poslednji procitani ynak.
    private bool eos;        // Indikator kraja toka.

    public Citaj (TextReader uut) { ut = uut; } // Inicijalizacija
                                                //   ulaznim tokom.
    public Citaj (string ime) {           // Otvaranje datoteke.
        ut = new StreamReader (ime); }

    public bool endS () { return eos; } // Da li je kraj toka?

    public char getChS () {             // Dohvatanje sledeceg znaka.
      int i = ut.Read ();
      return c = (eos = i == -1) ? ' ' : (char)i;
    }

    public char CharS () {              // Citanje jednog (nebelog) znaka.
      while (System.Char.IsWhiteSpace (c = getChS ()) && !eos);
      return !eos ? c : ' ';
    }

    public string StringS () {          // Citanje jedne reci.
      string s = "";
      while (System.Char.IsWhiteSpace (c = getChS ()) && !eos);
      if (eos) return "";
      s += c;
      while (!System.Char.IsWhiteSpace (c = getChS ()) && !eos) s += c;
      eos = false;
      return s;
    }

    public string LineS () {            // Citanje jednog reda teksta.
      string s = ut.ReadLine ();
      c = '\0';
      if (s != null) return s;
      else {eos = true; return ""; }
    }

    public void getNLS () {               // Preskakanje znakova do kraja reda.
        while (c!='\n' && !eos) c = getChS (); c = '\0'; }

    public byte ByteS () {              // Citanje podatka tipa byte.
      string s = StringS (); 
      return !eos ? System.Byte.Parse (s) : (byte)0; 
    }

    public sbyte SByteS () {            // Citanje podatka tipa sbyte.
      string s = StringS (); 
      return !eos ? System.SByte.Parse (s) : (sbyte)0; 
    }

    public short ShortS () {            // Citanje podatka tipa short.
      string s = StringS (); 
      return !eos ? Int16.Parse (s) : (short)0; 
    }

    public ushort UShortS () {          // Citanje podatka tipa ushort.
      string s = StringS (); 
      return !eos ? UInt16.Parse (s) : (ushort)0; 
    }

    public int IntS () {                // Citanje podatka tipa int.
      string s = StringS (); 
      return !eos ? Int32.Parse (s) : 0; 
    }

    public uint UIntS () {              // Citanje podatka tipa uint.
      string s = StringS (); 
      return !eos ? UInt32.Parse (s) : 0; 
    }

    public long LongS () {              // Citanje podatka tipa long.
      string s = StringS (); 
      return !eos ? Int64.Parse (s) : 0; 
    }
 
    public ulong ULongS () {            // Citanje podatka tipa ulong.
      string s = StringS (); 
      return !eos ? UInt64.Parse (s) : 0; 
    }

    public float FloatS () {            // Citanje podatka tipa float.
      string s = StringS (); 
      return !eos ? (float)System.Double.Parse (s) : 0; 
    }

    public double DoubleS () {          // Citanje podatka tipa double.
      string s = StringS (); 
      return !eos ? System.Double.Parse (s) : 0; 
    }

    // PODRSKA ZA CITANJE S GLAVNOG ULAZA.

    private static Citaj gl = new Citaj (Console.In); // Predstavnik gl.
    //   ulaza.
    public static bool   end    () { return gl.endS    (); } // Varijante
    public static char   getCh  () { return gl.getChS  (); } //   metoda
    public static char   Char   () { return gl.CharS   (); } //   koje
    public static string String () { return gl.StringS (); } //   citaju s
    public static string Line   () { return gl.LineS   (); } //   glavnog
    public static void   getNL  () {        gl.getNLS  (); } //   ulaza.
    public static byte   Byte   () { return gl.ByteS   (); }
    public static sbyte  SByte  () { return gl.SByteS  (); }
    public static short  Short  () { return gl.ShortS  (); }
    public static ushort UShort () { return gl.UShortS (); }
    public static int    Int    () { return gl.IntS    (); }
    public static uint   UInt   () { return gl.UIntS   (); }
    public static long   Long   () { return gl.LongS   (); }
    public static ulong  ULong  () { return gl.ULongS  (); }
    public static float  Float  () { return gl.FloatS  (); }
    public static double Double () { return gl.DoubleS (); }

  }  // class Citaj
} // namespace Usluge