// Kompl.cs - Klasa kompleksnih brojeva.

using System;

public struct Kompl {
  private double re, im; // Realni i imaginarni deo.

  public Kompl (double r, double i) { re = r; im = i; } // Konstruktori.
  public Kompl (double r)           { re = r; im = 0; }
  // Ne moze bez argumenata (generisani postavlja sve nule).

  public double Re {                                 // Realni deo:
    get { return re; }                               // - x = z.Re
    set { re = value; }                              // - z.Re = x
  }
  public double Im {                                 // Imaginarni deo:
    get { return im; }                               // - x = z.Im
    set { im = value; }                              // - z.im = x
  }
  public double Abs {                                // Apsolutna vrednost:
    get { return Math.Sqrt (re*re + im*im); }        // - x = z.Abs
    set {                                            // - z.Abs = x
      double arg = Arg;
      re = value * Math.Cos (arg); im = value * Math.Sin (arg);
    }
  }
  public double Arg {                                // Argument:
    get {                                            // - x = z.Arg
      return (re!=0 || im!=0) ? Math.Atan2 (im, re) : 0; }
    set {                                            // - z.Arg = x
      double abs = Abs;
      re = abs * Math.Cos (value); im = abs * Math.Sin (value);
    }
  }
  public static Kompl operator~ (Kompl z) {          // Konjugovan broj: ~a
    return new Kompl (z.re, -z.im);
  }
  public static Kompl operator++ (Kompl a) {         // ++a  a++
    a.re++; return a;
  }
  public static Kompl operator-- (Kompl a) {         // --a  a--
    a.re--; return a;
  }
  public static Kompl operator+ (Kompl a, Kompl b) { // a+b  a+=b
    return new Kompl (a.re+b.re, a.im+b.im);
  }
  public static Kompl operator- (Kompl a, Kompl b) { // a-b  a-=b
    return new Kompl (a.re-b.re, a.im-b.im);
  }
  public static Kompl operator* (Kompl a, Kompl b) { // a*b  a*=b
    return new Kompl (a.re*b.re-a.im*b.im, a.im*b.re+a.re*b.im);
  }
  public static Kompl operator/ (Kompl a, Kompl b) { // a/b  a/=b
    double c = b.re*b.re + b.im*b.im;
    return new Kompl ((a.re*b.re+a.im*b.im)/c,
                      (a.im*b.re-a.re*b.im)/c);
  }
  public static bool operator== (Kompl a, Kompl b) { // a==b
    return a.re==b.re && a.im==b.im;
  }
  public static bool operator!= (Kompl a, Kompl b) { // a!=b
    return a.re!=b.re || a.im!=b.im;
  }
  public static implicit operator Kompl (double r) { // Konverzija:
    return new Kompl (r);                            // - z = r
  }                                                  // - (Kompl)r
  public static Kompl Exp (Kompl a) {                // Kompl.exp(a)
    double abs = Math.Exp (a.re), arg = a.im;
    return new Kompl (abs*Math.Cos(arg), abs*Math.Sin(arg));
  }
  public static Kompl Log (Kompl a) {                // Kompl.log(a)
    return new Kompl (Math.Log(a.Abs), a.Arg);
  }
  public static Kompl Pow (Kompl a, Kompl b) {       // Kompl.pow(a,b)
    return Exp (b*Log(a)); }

  public override string ToString () {               // Tekstualni opis:
    return "(" + re + "," + im + ")";                // - z.ToString()
  }                                                  // - ""+z
}