// Matr.cs - Klasa matrica realnih brojeva.

namespace Matrica {
  using Usluge;
  using System;
  using System.Text;

  public class Matr {

    double[,] mat;                                      // Elementi matrice.

    public Matr (int m, int n) { mat = new double[m,n]; }  // Inicijaliza-
                                                           //   cija.
    public Matr (): this (10, 10) {}

    public int Vrs { get { return mat.GetLength(0); } } // Broj vrsta.

    public int Kol { get { return mat.GetLength(1); } } // Broj kolona.

    private void proveriInd (int i, int j) {       // Provera indeksa.
      if (i<0 || i>=Vrs || j<0 || j>=Kol) throw new GMatInd (i, j);
    }
    public double this[int i, int j] {             // Pristup elementu:
      get { proveriInd (i, j); return mat[i,j]; }  // - dohvatanje,
      set { proveriInd (i, j); mat[i,j] = value; } // - postavljanje.
    }
    public Matr Kopija () {                        // Stvaranje kopije.
      int v = Vrs, k = Kol;
      Matr m = new Matr (v, k);
      for (int i=0; i<v; i++)
        for (int j=0; j<k; j++)
          m.mat[i,j] = mat[i,j];
      return m;
    }
    private static void proveriDim (Matr m1, Matr m2) { // Provera dimenzija
      if (m1.Vrs != m2.Vrs || m1.Kol != m2.Kol )
        throw new GMatDim (m1, m2);
    }
    public static Matr operator+ (Matr m1, Matr m2) {   // m1+m2, m1+=m2
      proveriDim (m1, m2);
      int v = m1.Vrs, k = m1.Kol;
      Matr m = new Matr (v, k);
      for (int i=0; i<v; i++)
        for (int j=0; j<k; j++)
          m.mat[i,j] = m1.mat[i,j] + m2.mat[i,j];
      return m;
    }
    public static Matr operator- (Matr m1, Matr m2) {   // m1-m2, m1-=m2
      proveriDim (m1, m2);
      int v = m1.Vrs, k = m1.Kol;
      Matr m = new Matr (v, k);
      for (int i=0; i<v; i++)
        for (int j=0; j<k; j++)
          m.mat[i,j] = m1.mat[i,j] - m2.mat[i,j];
      return m;
    }
    public static Matr operator* (Matr m1, Matr m2) {   // m1*m2, m1*=m2
      if (m1.Kol != m2.Vrs) throw new GMatDim (m1, m2);
      Matr m = new Matr (m1.Vrs, m2.Kol);
      for (int i=0; i<m1.Vrs; i++)
        for (int k=0; k<m2.Kol; k++)
          for (int j=0; j<m1.Kol; j++)
            m.mat[i,k] += m1.mat[i,j] * m2.mat[j,k];
      return m;
    }

    public Matr citaj () {                              // Citanje matrice.
      Console.Write ("Vrs, kol? ");
      int vrs = Citaj.Int (), kol = Citaj.Int ();
      mat = new double [vrs,kol];
      for (int i=0; i<vrs; i++) {
        Console.Write ("Vrsta " + i + "? ");
        for (int j=0; j<kol; mat[i,j++]=Citaj.Double());
      }
      return this;
    }

    public override string ToString () {      // Stvaranje tekstualog opisa.
      StringBuilder s = new StringBuilder ();
      for (int i=0; i<Vrs; i++){
        for (int j=0; j<Kol; s.Append(mat[i,j++]).Append(' '));
        s.Append('\n');
      }
      return s.ToString ();
    }
  }
}