// Skladiste.cs - Klasa za uskladistavanje podataka.

namespace Skladista {
  using System.Threading;
  using System.Text;

  public class Skladiste {

    private static int ukId = 0; // Poslednje korisceni identifikator.
    private int id = ++ukId;     // Identifikator skladista.
    private int[] niz;           // Niz za uskladistavanje podataka.
    private int ulaz, izlaz;     // Mesto stavljanja i uzimanja podatka.
    private int pun;             // Broj popunjenih mesta.

    public Skladiste (int kap) {         // Inicijalizacija.
      niz = new int [kap]; }
  
    public void Stavi (int vredn) {      // Stavljanje podatka.
      lock (this) {
        while (pun == niz.Length) Monitor.Wait (this);
        niz[ulaz++] = vredn;
        if (ulaz == niz.Length) ulaz = 0;
        pun++;
        Monitor.PulseAll (this);
      }
    }
    public int Uzmi () {                 // Uzimanje podatka.
      lock (this) {
        while (pun == 0) Monitor.Wait (this);
        int vredn = niz[izlaz++];
        if (izlaz == niz.Length) izlaz = 0;
        pun--;
        Monitor.Pulse (this);
        return vredn;
      }
    }
    
    public override string ToString () { // Tekstualni opis.
      StringBuilder s = new StringBuilder ("Sklad " + id + ": ");
      lock (this) {
        for (int i=0; i<pun; i++)
          s.Append (niz[(izlaz+i) % niz.Length]).Append (' ');
      }
      return s.ToString ();
    }
  }
}