// Ugao.cs - Struktura uglova.

using System;
using Usluge;

public struct Ugao {
  private double ugao;                             // Ugao u radijanima.
  private const double FAKTOR = Math.PI / 180;     // Radijani u stepene.
                                                   // Konstruktori:
  public Ugao (double u) { ugao = u; }             // - na osnovu radijana,
   
  public Ugao (int stp, int min, int sek)          // - na osnovu stepeni.
    { ugao = rad (stp, min, sek); }
  public Ugao (int stp, int min): this (stp, min, 0) {}
  public Ugao (int stp): this (stp, 0, 0) {}

  private static double rad (int stp, int min, int sek)    // Stepeni u 
    { return ((sek / 60.0 + min) / 60 + stp) * FAKTOR; }    //   radijane.

  public double Rad {                              // Radijani:
    get { return ugao; }                           //   x = u.Rad;
    set { ugao = value; }                          //   u.Rad = x;
  }
    
  public int Stp {                                 // Stepeni:
    get { return (int) (ugao / FAKTOR); }          //   x = u.Stp;
    set { ugao = rad (value, Min, Sek); }          //   u.Stp = x;
  }
      
  public int Min {                                 // Minuti:
    get { return (int)(ugao/FAKTOR * 60) % 60; }   //   x = u.Min;
    set { ugao = rad (Stp, value, Min); }          //   u.Min = x;
  }
   
  public int Sek {                                 // Sekunde:
    get { return (int)(ugao/FAKTOR * 3600) % 60; } //   x = u.Sek;
    set { ugao = rad (Stp, Min, value); }          //   u.Sek = x;
  }
   
  public void razlozi (out int stp, out int min,   // Dohvatanje sva
                       out int sek)                //   tri dela.
    { stp = Stp; min = Min; sek = Sek; }
   
  public void postavi (int stp, int min, int sek)  // Postavljanje sva
    { ugao = rad (stp, min, sek); }                //   tri dela.

  public Ugao Zbir (Ugao u)               // Zbir dva ugla.
    { return new Ugao (ugao + u.ugao); }
        
  public Ugao Proizv (double a)           // Proizvod realnim brojem.
    { return new Ugao (ugao * a); }

  public void Citaj ()                    // Citanje u radijanima.
    { ugao = Usluge.Citaj.Double (); }

  public void CitajStep () {              // Citanje u stepenima.
    ugao = rad (Usluge.Citaj.Int (), 
                Usluge.Citaj.Int (),
                Usluge.Citaj.Int ());
  }

  public void Pisi ()                     // Pisanje u radijanima.
    { Console.Write (ugao); }
        
  public void PisiStep ()                 // Pisanje u stepenima.
    { Console.Write ("(" + Stp + ":" + Min + ":" + Sek + ")"); }
}